FlowbiteIcon class

Class for a single Icon (not IconData), based on constructors.

For instance: final Icon icon = FlowbiteIcon(FlowbiteSolidIcons.rocket);

If you're looking for IconData instead of Icon objects, please see FlowbiteSolidIcons class.

Inheritance

Constructors

FlowbiteIcon(IconData? icon, {Key? key, double? size = 24.0, double? fill, double? weight, double? grade, double? opticalSize, Color? color, List<Shadow>? shadows, String? semanticLabel, TextDirection? textDirection})
Constructor for Flowbite icons (size 24.0).
const

Properties

applyTextScaling → bool?
Whether to scale the size of this widget using the ambient MediaQuery's TextScaler.
finalinherited
blendMode → BlendMode?
The BlendMode to apply to the foreground of the icon.
finalinherited
color → Color?
The color to use when drawing the icon.
finalinherited
fill → double?
The fill for drawing the icon.
finalinherited
fontWeight → FontWeight?
The typeface thickness to use when painting the text (e.g., bold).
finalinherited
grade → double?
The grade (granular stroke weight) for drawing the icon.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
The icon to display. The available icons are described in Icons.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
opticalSize → double?
The optical size for drawing the icon.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
Semantic label for the icon.
finalinherited
shadows → List<Shadow>?
A list of Shadows that will be painted underneath the icon.
finalinherited
size → double?
The size of the icon in logical pixels.
finalinherited
textDirection → TextDirection?
The text direction to use for rendering the icon.
finalinherited
weight → double?
The stroke weight for drawing the icon.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited